/*******************************************************************************
 * syspovconfig.h
 *
 *
 * ---------------------------------------------------------------------------
 * Persistence of Vision Ray Tracer ('POV-Ray') version 3.7.
 * Copyright 1991-2013 Persistence of Vision Raytracer Pty. Ltd.
 *
 * POV-Ray is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * POV-Ray is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * ---------------------------------------------------------------------------
 * POV-Ray is based on the popular DKB raytracer version 2.12.
 * DKBTrace was originally written by David K. Buck.
 * DKBTrace Ver 2.0-2.12 were written by David K. Buck & Aaron A. Collins.
 * ---------------------------------------------------------------------------
 * $File: //depot/public/povray/3.x/vfe/unix/syspovconfig.h $
 * $Revision: #1 $
 * $Change: 6069 $
 * $DateTime: 2013/11/06 11:59:40 $
 * $Author: chrisc $
 *******************************************************************************/

#ifndef __SYSPOVCONFIG_H__
	#define __SYSPOVCONFIG_H__

#define fseek64(stream,offset,whence) fseeko(stream,offset,whence)
#define lseek64(handle,offset,whence) lseek(handle,offset,whence)
#define HAVE_GETRUSAGE
#define HAVE_CLOCK_GETTIME
#include "clock_gettime_stub.h"
#define	HAVE_GETTIMEOFDAY
#define USE_OFFICIAL_BOOST
#define POV_RAY_IS_OFFICIAL 0
#define IFF_SWITCH_CAST (long)
#define NON_UNIX_OPENEXR_HEADERS
#define HAVE_NANOSLEEP
	#define SYS_HAS_GRAYSCALE		// grayscale output supported in SYS file type
	#define DEFAULT_OUTPUT_FORMAT    kPOVList_FileType_PNG
	#define DEFAULT_DISPLAY_GAMMA 1.8
	#define DEFAULT_FILE_GAMMA_TYPE kPOVList_GammaType_SRGB
	#define DEFAULT_FILE_GAMMA 2.2
	#define DEFAULT_ITEXTSTREAM_BUFFER_SIZE 65536

	#define POV_FILE_SEPARATOR_2  '/'
	#define POV_FILE_SEPARATOR '/'
	#define POV_LONG long long
	#define POV_ULONG unsigned long long

/* I/O restrictions. */
#define IO_RESTRICTIONS_DISABLED 0

/* Name of package */
#define PACKAGE "POV-Ray Command line Mac"

/* Define to the full name of this package. */
#define PACKAGE_NAME PACKAGE
#error "You must provide your own e-mail address and name. Keep the (c) for clock_gettime_stub.c!!"
	#define DISTRIBUTION_MESSAGE_2 "YOUR NAME ANE E-MAIL ADDRESS\nclock_gettime_stub.c Copyright (c), MM Weiss All rights reserved\n"

	#if defined(__i386__)
		#define BUILD_ARCH "AppleIntel32"
	#elif defined(__x86_64__)
		#define BUILD_ARCH "AppleIntel64"
	#endif

#define COMPILER_VER __VERSION__
/* Supported image formats. */
#define BUILTIN_IMG_FORMATS "gif tga iff ppm pgm hdr png jpeg tiff"

/* I/O restrictions. */
#define BUILTIN_IO_RESTRICTIONS "enabled"

/* X Window display. */
#define BUILTIN_XWIN_DISPLAY "disabled"

/* Host platform. */
	#if defined(__i386__)
		#define BUILT_FOR "Intel-based Macintosh 32bit"
	#elif defined(__x86_64__)
		#define BUILT_FOR "Intel-based Macintosh 64bit"
	#endif

/* Unsupported image formats. */
#define MISSING_IMG_FORMATS "none"
/* Base version number of package. */
#define VERSION_BASE "3.7"
/* See source/octree.cpp for details. */
/* #undef C99_COMPATIBLE_RADIOSITY */


/* Define to 1 if you have the `asinh' function. */
#define HAVE_ASINH 1

/* define if the Boost library is available */
#define HAVE_BOOST /**/

/* define if the Boost::Thread library is available */
#define HAVE_BOOST_THREAD /**/
/* Define if you have POSIX threads libraries and header files. */
#define HAVE_PTHREAD 1


/* Define to 1 if you have the `readlink' function. */
#define HAVE_READLINK 1

/* Define to 1 if you have the <sys/resource.h> header file. */
#define HAVE_SYS_RESOURCE_H 1


/* Define to 1 if you have the <sys/time.h> header file. */
#define HAVE_SYS_TIME_H 1


/* Define to 1 if you have the <time.h> header file. */
#define HAVE_TIME_H 1


/* I/O restrictions. */
#define IO_RESTRICTIONS_DISABLED 0

#ifndef STD_TYPES_DECLARED
	#define STD_TYPES_DECLARED
	// the following types are used extensively throughout the POV source and hence are
	// included and named here for reasons of clarity and convenience.

	#include <exception>
	#include <stdexcept>
	#include <string>
	#include <vector>
	#include <list>
	#include <boost/shared_ptr.hpp>

	// when we say 'string' we mean std::string
	using std::string;

	// and vector is a std::vector
	using std::vector;

	// yup, list too
	using std::list;

	// runtime_error is the base of our Exception class, plus is referred
	// to in a few other places.
	using std::runtime_error;

	// C++0x has a shared_ptr, but we currently use the boost one. alas, Visual Studio 2010
	// pulls in the std::tr1::shared_ptr in some headers (particularly <memory>), and we thus
	// have to either specifically nominate boost::shared_ptr wherever we use it, or typedef
	// it. C++ doesn't [currently] support template typedefs but we could use the struct rebind
	// workaround. for the moment it's being left unfixed.
	using boost::shared_ptr;

#endif // STD_POV_TYPES_DECLARED

	
	#include <algorithm>
	#include <stdarg.h>
	#include <stdio.h>
	#include <string.h>
	using std::max;
	using std::min;
	#include "../vfeconf.h"


	#define METADATA_PLATFORM_STRING POVRAY_PLATFORM_NAME
	#define METADATA_COMPILER_STRING __VERSION__

	#define DELETE_FILE(name)  unlink(name)

	# define FILE_NAME_LENGTH   PATH_MAX
	#ifndef MAX_PATH
		#define MAX_PATH PATH_MAX
	#endif



	#define ALTMAIN
	#define NEW_LINE_STRING "\n"  // default
	#define SYS_DEF_EXT     ""


	#define MEM_STATS 1 




#endif
